@@ -33,9 +33,10 @@
 #  define KCONTACTS_DEPRECATED_NO_EXPORT KCONTACTS_NO_EXPORT KCONTACTS_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KCONTACTS_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KCONTACTS_NO_DEPRECATED
+#    define KCONTACTS_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
